@@ -73,13 +73,15 @@ class DataBaseWorker:
             self.schema = self.cred["schema"]
         else:
             self.schema = self.cred["database"]
-        self.logger.info("try to connect to {}...".format(self.db))
+        self.logger.info("try to connect to {}, host {}...".format(self.db, self.cred["host"]))
         self.conn = self.engine.connect()
-        self.logger.info("connecting is successful")
+        self.logger.info("connecting to {}, host {} is successful".format(self.db, self.cred["host"]))
 
     def __del__(self):
         if self.conn is not None:
+            self.logger.info("Connecting to {}, host {} is closed".format(self.db, self.cred["host"]))
             self.conn.close()
+            self.engine.dispose()
 
     def __check_dialect(self):
         if self.db not in base_converter_params.keys():
